@@ -1076,12 +1076,16 @@ class Booltest(object):
         if tvsize < 0:
             raise ValueError('Negative TV size: %s' % tvsize)
 
-        coef = 8 if not self.do_halving else 4
-        if (tvsize * coef) % self.blocklen != 0:
-            rem = (tvsize * coef) % self.blocklen
+        # multiplier when not byte-aligned to make it byte-aligned on tvsize.
+        align_blocklen = self.blocklen if not self.do_halving else 2 * self.blocklen
+        align_mutl = common.comp_byte_align_multiplier(align_blocklen, 8 if not self.do_halving else 16)
+        aligned_blocklen = align_blocklen * align_mutl
+
+        if (tvsize * 8) % aligned_blocklen != 0:
             logger.warning('Input data size not aligned to the block size. '
-                           'Input bytes: %d, block bits: %d, rem: %d' % (tvsize, self.blocklen, rem))
-            tvsize -= rem // coef
+                           'Input bytes: %d, block bits: %d, align_mutl: %d, align_block: %s, halving: %s'
+                           % (tvsize, self.blocklen, align_mutl, aligned_blocklen, self.do_halving))
+            tvsize = (((tvsize * 8) // aligned_blocklen) * aligned_blocklen) // 8
             logger.info('Updating TV to %d' % tvsize)
         return int(tvsize)
 
@@ -1323,8 +1327,8 @@ class Booltest(object):
                 break
 
             if (len(data) * 8 % self.hwanalysis.blocklen) != 0:
-                logger.info('Not aligned block read, terminating. Data left: %s bits, block size: %s bits'
-                            % (len(data) * 8, self.hwanalysis.blocklen))
+                logger.info('Not aligned block read, terminating. Data left: %s bits, block size: %s bits, tv %s'
+                            % (len(data) * 8, self.hwanalysis.blocklen, tvsize))
                 break
 
             with self.timer_data_bins:
